pub enum ChainError {
Show 48 variants
CryptoError(CryptoError),
ArithmeticError(ArithmeticError),
ViewError(ViewError),
ExecutionError(Box<ExecutionError>, ChainExecutionContext),
InactiveChain(ChainId),
MissingCrossChainUpdates {
chain_id: ChainId,
bundles: Vec<(ChainId, BlockHeight)>,
},
UnexpectedMessage {
chain_id: ChainId,
origin: ChainId,
bundle: Box<MessageBundle>,
previous_bundle: Box<MessageBundle>,
},
IncorrectMessageOrder {
chain_id: ChainId,
origin: ChainId,
bundle: Box<MessageBundle>,
next_height: BlockHeight,
next_index: u32,
},
CannotRejectMessage {
chain_id: ChainId,
origin: ChainId,
posted_message: Box<PostedMessage>,
},
CannotSkipMessage {
chain_id: ChainId,
origin: ChainId,
bundle: Box<MessageBundle>,
},
IncorrectBundleTimestamp {
chain_id: ChainId,
bundle_timestamp: Timestamp,
block_timestamp: Timestamp,
},
InvalidSigner,
UnexpectedBlockHeight {
expected_block_height: BlockHeight,
found_block_height: BlockHeight,
},
UnexpectedPreviousBlockHash,
BlockHeightOverflow,
InvalidBlockTimestamp {
parent: Timestamp,
new: Timestamp,
},
InsufficientRound(Round),
InsufficientRoundStrict(Round),
WrongRound(Round),
HasIncompatibleConfirmedVote(BlockHeight, Round),
MustBeNewerThanLockingBlock(BlockHeight, Round),
MissingEarlierBlocks {
current_block_height: BlockHeight,
},
CertificateValidatorReuse,
CertificateRequiresQuorum,
JustificationRoundsNotIncreasing,
JustificationUnlockingRoundMismatch,
JustificationCommitmentMismatch,
JustificationChainNotBelowCertificate,
FalseFirstRoundAttestation,
EquivocationProofSameBlock,
EquivocationProofDifferentChainOrHeight,
EquivocationProofNoLockViolation,
EquivocationProofNoFirstRoundViolation,
EquivocationProofValidJustification,
InboxGapDetected {
chain_id: ChainId,
origin: ChainId,
expected_height: BlockHeight,
actual_height: BlockHeight,
},
InternalError(String),
CorruptedChainState(String),
BlockProposalTooLarge(usize),
BcsError(Error),
MultipleEpochAdvances {
start_epoch: Epoch,
end_epoch: Epoch,
},
ClosedChain,
EmptyBlock,
AuthorizedApplications(Vec<ApplicationId>),
MissingMandatoryApplications(Vec<ApplicationId>),
MissingOracleResponseList,
RoundDoesNotTimeOut,
NotTimedOutYet(Timestamp),
CheckpointPreconditionFailed(&'static str),
}Expand description
An error that occurred while validating or executing a block on a chain.
Variants
CryptoError(CryptoError)
ArithmeticError(ArithmeticError)
ViewError(ViewError)
ExecutionError(Box<ExecutionError>, ChainExecutionContext)
InactiveChain(ChainId)
MissingCrossChainUpdates
Fields
bundles: Vec<(ChainId, BlockHeight)>The missing incoming message bundles, as (origin chain, height) pairs that must
all be received before this block can be validated. The validator reports every
missing bundle at once so the client can fetch them in a single round.
UnexpectedMessage
IncorrectMessageOrder
CannotRejectMessage
CannotSkipMessage
IncorrectBundleTimestamp
InvalidSigner
UnexpectedBlockHeight
UnexpectedPreviousBlockHash
BlockHeightOverflow
InvalidBlockTimestamp
InsufficientRound(Round)
InsufficientRoundStrict(Round)
WrongRound(Round)
HasIncompatibleConfirmedVote(BlockHeight, Round)
MustBeNewerThanLockingBlock(BlockHeight, Round)
MissingEarlierBlocks
Fields
current_block_height: BlockHeightCertificateValidatorReuse
CertificateRequiresQuorum
JustificationRoundsNotIncreasing
JustificationUnlockingRoundMismatch
JustificationCommitmentMismatch
JustificationChainNotBelowCertificate
FalseFirstRoundAttestation
EquivocationProofSameBlock
EquivocationProofDifferentChainOrHeight
EquivocationProofNoLockViolation
EquivocationProofNoFirstRoundViolation
EquivocationProofValidJustification
InboxGapDetected
InternalError(String)
CorruptedChainState(String)
BlockProposalTooLarge(usize)
BcsError(Error)
MultipleEpochAdvances
ClosedChain
EmptyBlock
AuthorizedApplications(Vec<ApplicationId>)
MissingMandatoryApplications(Vec<ApplicationId>)
MissingOracleResponseList
RoundDoesNotTimeOut
NotTimedOutYet(Timestamp)
CheckpointPreconditionFailed(&'static str)
Implementations
Sourceimpl ChainError
impl ChainError
Sourcepub fn is_local(&self) -> bool
pub fn is_local(&self) -> bool
Returns whether this error is caused by an issue in the local node.
Returns false whenever the error could be caused by a bad message from a peer.
Sourcepub fn error_type(&self) -> String
pub fn error_type(&self) -> String
Returns the qualified error variant name for the error_type metric label,
e.g. "ChainError::UnexpectedBlockHeight".
For ExecutionError variants, delegates to ExecutionError::error_type()
to surface the underlying error name rather than just "ExecutionError".